@@ -59,8 +59,6 @@ def ensuredirs(*directories):
                 raise
 
 
-TAR_FILTERS = {'.gz': '-z', '.bz2': '-j'}
-
 class SourcePackage(namedtuple(
     '_SourcePackage', 'name version buildtype url_template'),
                     SubprocessMixin):
@@ -78,7 +76,7 @@ class SourcePackage(namedtuple(
             try:
                 self.log.info('downloading %s to %s', self.url, target)
                 self._check_call(['wget', '-O', target, self.url])
-            except subprocess.CalledProcessError:
+            except:
                 if os.path.isfile(target):
                     os.unlink(target)
                 raise
@@ -90,8 +88,8 @@ class SourcePackage(namedtuple(
         archive = self.download(download_directory)
         ext = os.path.splitext(archive)[1]
         self.log.info('extracting %s to %s', archive, target_directory)
-        self._check_call(['tar', '-x', TAR_FILTERS[ext], '-f',
-                          archive, '-C', target_directory])
+        self._check_call(['tar', '-x', '-a', '-f', archive,
+                          '-C', target_directory])
         return self.buildtype(os.path.join(
             target_directory, '{0.name}-{0.version}'.format(self)))
 
@@ -155,19 +153,43 @@ class PyQtBuild(SipBuild):
 
 class CMakeBuild(Build):
 
-     @property
-     def build_directory(self):
-         return os.path.join(self.source_directory, 'build')
+    configure_options = []
 
-     def initialize(self):
-         self.log.info('creating build directory')
-         ensuredirs(self.build_directory)
+    @property
+    def build_directory(self):
+        return os.path.join(self.source_directory, 'build')
 
-     def configure(self):
-         self.log.info('configuring in %s', self.build_directory)
-         cmd = ['cmake', '-DCMAKE_INSTALL_PREFIX={0}'.format(sys.prefix),
-                '-DCMAKE_BUILD_TYPE=RelWithDebInfo', self.source_directory]
-         self._check_call(cmd, cwd=self.build_directory)
+    def initialize(self):
+        self.log.info('creating build directory')
+        ensuredirs(self.build_directory)
+
+    def configure(self):
+        self.log.info('configuring in %s', self.build_directory)
+        cmd = ['cmake', '-DCMAKE_INSTALL_PREFIX={0}'.format(sys.prefix),
+               '-DCMAKE_BUILD_TYPE=RelWithDebInfo']
+        cmd.extend(self.configure_options)
+        cmd.append(os.path.abspath(self.source_directory))
+        self._check_call(cmd, cwd=self.build_directory)
+
+
+class PySideBuild(CMakeBuild):
+    configure_options = [
+        '-DDISABLE_{0}=ON'.format(mod) for mod in
+        ('QtGui', 'QtMultimedia', 'QtNetwork', 'QtOpenGL', 'QtScript',
+         'QtScriptTools', 'QtSql', 'QtSvg', 'QtWebKit', 'QtXml',
+         'QtXmlPatterns', 'QtDeclarative', 'phonon', 'QtUiTools', 'QtHelp',
+         'QtTest')]
+
+
+class AutotoolsBuild(Build):
+    configure_options = ['--prefix', sys.prefix]
+
+    def configure(self):
+        self.log.info('configuring %s with %r', self.build_directory,
+                      self.configure_options)
+        cmd = ['./configure']
+        cmd.extend(self.configure_options)
+        self._check_call(cmd, cwd=self.build_directory)
 
 
 RIVERBANK_DOWNLOAD_URL = 'http://www.riverbankcomputing.com/static/Downloads/{0}'
@@ -189,10 +211,17 @@ PYSIDE_SOURCES = [
                   PYSIDE_DOWNLOAD_URL.format('{name}-{version}.tar.bz2')),
     SourcePackage('shiboken', '0.5.0', CMakeBuild,
                   PYSIDE_DOWNLOAD_URL.format('{name}-{version}.tar.bz2')),
-    SourcePackage('pyside', 'qt4.6+0.4.1', CMakeBuild,
+    SourcePackage('pyside', 'qt4.6+0.4.1', PySideBuild,
                   PYSIDE_DOWNLOAD_URL.format('{name}-{version}.tar.bz2')),
     ]
 
+GNOME_DOWNLOAD_URL = 'http://ftp.gnome.org/pub/GNOME/sources/{0}'
+
+GOBJECT_SOURCES = [
+    SourcePackage('pygobject', '2.26.0', AutotoolsBuild,
+                  GNOME_DOWNLOAD_URL.format(
+                      '{name}/2.26/{name}-{version}.tar.bz2'))]
+
 
 def build_all(sources, download_directory, build_directory):
     for source in sources:
@@ -215,6 +244,15 @@ def have_pyside_qtcore():
         return False
 
 
+def have_gobject():
+    for lib in ('glib', 'gobject'):
+        try:
+            __import__(lib)
+        except ImportError:
+            return False
+    return True
+
+
 def main():
     parser = OptionParser(usage='%prog download_directory build_directory')
     parser.add_option('--debug', action='store_const', dest='loglevel',
@@ -229,16 +267,23 @@ def main():
 
     download_directory, build_directory = args
     ensuredirs(download_directory, build_directory)
+
     if not have_pyqt4_qtcore(PYQT4_SOURCES[1].version):
         build_all(PYQT4_SOURCES, download_directory, build_directory)
 
-    if sys.version_info[0] < 3 and not have_pyside_qtcore():
-        lib_paths = os.environ.get('LD_LIBRARY_PATH', '').split(os.pathsep)
-        lib_paths.insert(0, os.path.join(sys.prefix, 'lib'))
-        lib_path = os.pathsep.join(lib_paths)
-        logging.info('setting library path to %r', lib_path)
-        os.environ['LD_LIBRARY_PATH'] = lib_path
-        build_all(PYSIDE_SOURCES, download_directory, build_directory)
+    if sys.version_info[0] < 3:
+        # pyside and pygobject are not available for python 3 yet
+        if not have_pyside_qtcore():
+            lib_paths = os.environ.get(
+                'LD_LIBRARY_PATH', '').split(os.pathsep)
+            lib_paths.insert(0, os.path.join(sys.prefix, 'lib'))
+            lib_path = os.pathsep.join(lib_paths)
+            logging.info('setting library path to %r', lib_path)
+            os.environ['LD_LIBRARY_PATH'] = lib_path
+            build_all(PYSIDE_SOURCES, download_directory, build_directory)
+
+        if not have_gobject():
+            build_all(GOBJECT_SOURCES, download_directory, build_directory)
 
 
 if __name__ == '__main__':
