@@ -20,11 +20,12 @@ release = pyudev.__version__
 
 html_theme = 'default'
 html_static_path = []
+html_domain_indices = ['py-modindex']
 
 intersphinx_mapping = {'python': ('http://docs.python.org/', None)}
 
 issuetracker = 'github'
-issuetracker_user = u'lunaryorn'
+issuetracker_user = 'lunaryorn'
 
 
 def setup(app):
