@@ -1,20 +1,19 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2010 Sebastian Wiesner <lunaryorn@googlemail.com>
+# Copyright (C) 2010 Sebastian Wiesner <lunaryorn@googlemail.com>
 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# This library is free software; you can redistribute it and/or modify it
+# under the terms of the GNU Lesser General Public License as published by the
+# Free Software Foundation; either version 2.1 of the License, or (at your
+# option) any later version.
 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This library is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+# for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this library; if not, write to the Free Software Foundation,
+# Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 from __future__ import unicode_literals
 
@@ -196,7 +195,7 @@ def test_enable_receiving_mock(monitor):
 
 def test_enable_receiving_error_mock(context, monitor, socket_path):
     with py.test.patch_libudev('udev_monitor_enable_receiving') as func:
-        with mock.patch('pyudev._monitor.get_libudev_errno') as get_errno:
+        with mock.patch('pyudev.monitor.get_libudev_errno') as get_errno:
             get_errno.return_value = errno.ENOENT
             func.return_value = 1
             with py.test.raises(EnvironmentError) as exc_info:
@@ -249,7 +248,7 @@ def test_receive_device_mock(monitor):
 
 def test_receive_device_error_mock(monitor):
     with py.test.patch_libudev('udev_monitor_receive_device') as func:
-        with mock.patch('pyudev._monitor.get_libudev_errno') as errorfunc:
+        with mock.patch('pyudev.monitor.get_libudev_errno') as errorfunc:
             func.return_value = None
             errorfunc.return_value = 0
             with py.test.raises(EnvironmentError) as exc_info:
